[Scummvm-cvs-logs] scummvm master -> 7e66cbd468a5b89eaf170d5e0fb3bb312365628c

bluegr md5 at scummvm.org
Tue Jun 26 10:14:45 CEST 2012


This automated email contains information about 1 new commit which have been
pushed to the 'scummvm' repo located at https://github.com/scummvm/scummvm .

Summary:
7e66cbd468 SCI: Rename a parameter in validateExportFunc()


Commit: 7e66cbd468a5b89eaf170d5e0fb3bb312365628c
    https://github.com/scummvm/scummvm/commit/7e66cbd468a5b89eaf170d5e0fb3bb312365628c
Author: Filippos Karapetis (md5 at scummvm.org)
Date: 2012-06-26T01:13:14-07:00

Commit Message:
SCI: Rename a parameter in validateExportFunc()

This ensures that it won't be confused with a function with the same name

Changed paths:
    engines/sci/engine/script.cpp
    engines/sci/engine/script.h



diff --git a/engines/sci/engine/script.cpp b/engines/sci/engine/script.cpp
index 57334b8..d4143dc 100644
--- a/engines/sci/engine/script.cpp
+++ b/engines/sci/engine/script.cpp
@@ -385,7 +385,7 @@ void Script::setLockers(int lockers) {
 	_lockers = lockers;
 }
 
-uint32 Script::validateExportFunc(int pubfunct, bool relocateSci3) {
+uint32 Script::validateExportFunc(int pubfunct, bool relocSci3) {
 	bool exportsAreWide = (g_sci->_features->detectLofsType() == SCI_VERSION_1_MIDDLE);
 
 	if (_numExports <= pubfunct) {
@@ -401,7 +401,7 @@ uint32 Script::validateExportFunc(int pubfunct, bool relocateSci3) {
 	if (getSciVersion() != SCI_VERSION_3) {
 		offset = READ_SCI11ENDIAN_UINT16(_exportTable + pubfunct);
 	} else {
-		if (!relocateSci3)
+		if (!relocSci3)
 			offset = READ_SCI11ENDIAN_UINT16(_exportTable + pubfunct) + getCodeBlockOffsetSci3();
 		else
 			offset = relocateOffsetSci3(pubfunct * 2 + 22);
diff --git a/engines/sci/engine/script.h b/engines/sci/engine/script.h
index 1fc8caf..0b49920 100644
--- a/engines/sci/engine/script.h
+++ b/engines/sci/engine/script.h
@@ -197,11 +197,11 @@ public:
 	 * Validate whether the specified public function is exported by
 	 * the script in the specified segment.
 	 * @param pubfunct		Index of the function to validate
 	 * @param relocateSci3  Decide whether to relocate this SCI3 public function or not
 	 * @return				NULL if the public function is invalid, its
 	 * 						offset into the script's segment otherwise
 	 */
-	uint32 validateExportFunc(int pubfunct, bool relocateSci3);
+	uint32 validateExportFunc(int pubfunct, bool relocSci3);
 
 	/**
 	 * Marks the script as deleted.
@@ -197,11 +197,11 @@ public:
 	 * the script in the specified segment.
 	 * @param pubfunct		Index of the function to validate
-	 * @param relocateSci3  Decide whether to relocate this SCI3 public function or not
+	 * @param relocSci3     Decide whether to relocate this SCI3 public function or not
 	 * @return				NULL if the public function is invalid, its
 	 * 						offset into the script's segment otherwise






More information about the Scummvm-git-logs mailing list